@@ -8,7 +8,10 @@ from .exception import PyCsvXlsException
 
 class CSVSniffer:
     def __init__(
-        self, main_path: str, file_startswith: str = "", fields: typing.List = []
+        self,
+        main_path: str,
+        file_startswith: str = "",
+        fields: typing.List = [],
     ):
         self.__is_file: bool = os.path.isfile(main_path)
         self.__file_startswith: str = file_startswith
@@ -21,7 +24,7 @@ class CSVSniffer:
         self.__fields: typing.List = fields
         self.__start_row_flag: bool = not self.__fields
 
-    def get_files_with_lines_for_set_dir(self) -> typing.List:
+    def get_dir_files_with_lines(self) -> typing.List:
         try:
             return list(self.__main_dir_sniffer())
         except Exception as e:
